1.0.0 API documentation: GLM_GTX_functions

| 1.0.0 API documentation

Functions
GLM_GTX_functions
Experimental extensions

## Functions
template<typename T >
GLM_FUNC_DECL T | gauss (T x, T ExpectedValue, T StandardDeviation)
| 1D gauss function More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | gauss (vec< 2, T, Q > const &Coord, vec< 2, T, Q > const &ExpectedValue, vec< 2, T, Q > const &StandardDeviation)
| 2D gauss function More...

## Detailed Description

Include <glm/gtx/functions.hpp> to use the features of this extension.

List of useful common functions.

## Function Documentation

## ◆ gauss() [1/2]

GLM_FUNC_DECL T glm::gauss | ( | T | x,
|  | T | ExpectedValue,
|  | T | StandardDeviation
| ) |  |

1D gauss function

See also
  GLM_GTC_epsilon

## ◆ gauss() [2/2]

GLM_FUNC_DECL T glm::gauss | ( | vec< 2, T, Q > const & | Coord,
|  | vec< 2, T, Q > const & | ExpectedValue,
|  | vec< 2, T, Q > const & | StandardDeviation
| ) |  |

2D gauss function

See also
  GLM_GTC_epsilon